<?php

App::uses('EvRobotsAppController', 'EvRobots.Controller');

class RobotsController extends EvRobotsAppController {

/**
 * Override the default functionality and have a simple form to update the robots.txt
 * If the file isn't writable, display a template saying so.
 *
 * @return void
 */
	public function admin_index() {
		if (!$this->Permissions->hasSuperAdminPermission($this->Auth->user())) {
			$this->Flash->fail(['title' => 'Permissions Error', 'description' => 'You do not have the correct permissions to be in this area.']);
			$this->redirect('/admin');
		}

		$this->viewPath = 'Robots';
		$robotsFilepath = APP . WEBROOT_DIR . '/robots.txt';

		$this->_updateRobotsPermissions(true);
		if (!is_writable($robotsFilepath)) {
			$this->view = 'not_writable';
		} else {
			if ($this->request->is(['post']) && isset($this->request->data['Robots']['content'])) {
				$robotsFile = fopen($robotsFilepath, 'wb+');

				if (fwrite($robotsFile, $this->request->data['Robots']['content'])) {
					$this->Flash->success(['title' => 'Update Successful', 'description' => 'Your robots.txt file has been updated']);

					$emailUpdatesTo = !empty(Configure::read('EvRobots.emailUpdatesTo')) ? Configure::read('EvRobots.emailUpdatesTo') : 'marketing@evoluted.net';

					$Email = new CustomEmail();
					$Email->deliver($emailUpdatesTo, $_SERVER['HTTP_HOST'] . ' \'s robots.txt file updated.', nl2br($this->request->data['Robots']['content']), Configure::read('email.config'), true);
				} else {
					$this->Flash->fail(['title' => 'Update Failed', 'description' => 'Your robots.txt file has not been updated']);
				}

				fclose($robotsFile);

				$this->redirect($this->here);
			}

			$this->set('robotsContent', file_get_contents($robotsFilepath));
			$this->view = 'writable';
		}

		$this->_updateRobotsPermissions(false);
	}

	protected function _updateRobotsPermissions($writable = false) {
		$permission = $writable ? 0666 : 0644;

		return chmod(APP . WEBROOT_DIR . '/robots.txt', $permission);
	}
}
